@@ -30,6 +30,7 @@
 #include <fcntl.h>
 #include <string.h>
 #include <errno.h>
+#include <time.h>
 #include <sys/mman.h>
 
 #include "maker.h"
@@ -241,7 +242,8 @@ static void hhm_set_error(hardhat_maker_t *hhm, const char *fmt, ...) {
 	if(!hhm)
 		return;
 
-	free(hhm->error);
+	if(hhm->error != enomem)
+		free(hhm->error);
 	hhm->error = malloc(4096);
 	if(hhm->error) {
 		va_start(ap, fmt);
@@ -255,6 +257,23 @@ static void hhm_set_error(hardhat_maker_t *hhm, const char *fmt, ...) {
 	}
 }
 
+static uint32_t makeseed(void) {
+	struct timespec ts[5];
+	int clocks = 2;
+	clock_gettime(CLOCK_REALTIME, ts);
+	clock_gettime(CLOCK_MONOTONIC, ts + 1);
+#ifdef CLOCK_MONOTONIC_RAW
+	clock_gettime(CLOCK_MONOTONIC_RAW, ts + clocks++);
+#endif
+#ifdef CLOCK_PROCESS_CPUTIME_ID
+	clock_gettime(CLOCK_PROCESS_CPUTIME_ID, ts + clocks++);
+#endif
+#ifdef CLOCK_THREAD_CPUTIME_ID
+	clock_gettime(CLOCK_THREAD_CPUTIME_ID, ts + clocks++);
+#endif
+	return calchash_murmur3((const void *)ts, sizeof *ts * clocks, getpid());
+}
+
 /* Allocate and initialize a hardhat_maker_t structure.
 	Returns NULL on failure, with errno set to the problem. */
 export hardhat_maker_t *hardhat_maker_new(const char *filename) {
@@ -272,6 +291,8 @@ export hardhat_maker_t *hardhat_maker_new(const char *filename) {
 
 	*hhm = hardhat_maker_0;
 
+	hhm->superblock.hashseed = makeseed();
+
 	hhm->filename = strdup(filename);
 	if(!hhm->filename) {
 		err = errno;
@@ -403,7 +424,7 @@ export bool hardhat_maker_add(hardhat_maker_t *hhm, const void *key, uint16_t ke
 
 	/* Check if the entry isn't already in the hash table.
 		If it is, return true. If not, add it and continue. */
-	hash = calchash(key, (size_t)keylen);
+	hash = calchash_murmur3(key, (size_t)keylen, hhm->superblock.hashseed);
 	ht = hhm->hashtable;
 	hp = hash % ht->size;
 	for(;;) {
@@ -676,7 +697,7 @@ export bool hardhat_maker_finish(hardhat_maker_t *hhm) {
 				ht->buf = he;
 			}
 			he = ht->buf + pfxnum++;
-			he->hash = calchash(cur, endlen);
+			he->hash = calchash_murmur3(cur, endlen, hhm->superblock.hashseed);
 			he->data = i;
 		}
 		prev = cur;
@@ -703,11 +724,11 @@ export bool hardhat_maker_finish(hardhat_maker_t *hhm) {
 	/* Create and write out the superblock */
 	memcpy(hhm->superblock.magic, HARDHAT_MAGIC, sizeof hhm->superblock.magic);
 	hhm->superblock.byteorder = UINT64_C(0x0123456789ABCDEF);
-	hhm->superblock.version = UINT32_C(1);
+	hhm->superblock.version = UINT32_C(2);
 	hhm->superblock.entries = num;
 	hhm->superblock.prefixes = pfxnum;
 	hhm->superblock.filesize = hhm->off;
-	hhm->superblock.checksum = calchash((const void *)&hhm->superblock, sizeof hhm->superblock - 4);
+	hhm->superblock.checksum = calchash_murmur3((const void *)&hhm->superblock, sizeof hhm->superblock - 4, hhm->superblock.hashseed);
 
 	if(fseek(db, 0, SEEK_SET) == -1) {
 		hhm_set_error(hhm, "seeking in %s failed: %m", hhm->filename);
