@@ -1,9 +1,7 @@
-context("test-spruce")
-
 test_that("spruce - numeric", {
   spruced <- spruce_numeric(1:5)
 
-  expect_is(spruced, "tbl_df")
+  expect_s3_class(spruced, "tbl_df")
   expect_equal(colnames(spruced), ".pred")
 
   expect_error(spruce_numeric("hi"))
@@ -11,10 +9,9 @@ test_that("spruce - numeric", {
 })
 
 test_that("spruce - class", {
-
   spruced <- spruce_class(factor(letters[1:5]))
 
-  expect_is(spruced, "tbl_df")
+  expect_s3_class(spruced, "tbl_df")
   expect_equal(colnames(spruced), ".pred_class")
 
   expect_error(spruce_class(1))
@@ -22,13 +19,12 @@ test_that("spruce - class", {
 })
 
 test_that("spruce - prob", {
-
   pred_levels <- letters[1:5]
   prob_matrix <- matrix(.5, ncol = 5, nrow = 2)
 
   spruced <- spruce_prob(pred_levels, prob_matrix)
 
-  expect_is(spruced, "tbl_df")
+  expect_s3_class(spruced, "tbl_df")
   expect_equal(colnames(spruced), paste0(".pred_", pred_levels))
 
   expect_error(spruce_prob(1, prob_matrix))
@@ -54,5 +50,4 @@ test_that("spruce - prob", {
     spruce_prob(c("a"), matrix(1, ncol = 2)),
     "2"
   )
-
 })
